summaryrefslogtreecommitdiffstats
path: root/kmrml/kmrml/lib/mrml_utils.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 15:36:38 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 15:36:38 -0600
commit353ee75c29c4f6fb5ba22de5e2d1418cb9506ace (patch)
tree7fc7809a5521596c075e8c0e9369d4c270c73f1d /kmrml/kmrml/lib/mrml_utils.cpp
parent4cdb763932d3379a368cea2b8d60baadbf5c4b44 (diff)
downloadtdegraphics-353ee75c29c4f6fb5ba22de5e2d1418cb9506ace.tar.gz
tdegraphics-353ee75c29c4f6fb5ba22de5e2d1418cb9506ace.zip
Rename kioslaves
Diffstat (limited to 'kmrml/kmrml/lib/mrml_utils.cpp')
-rw-r--r--kmrml/kmrml/lib/mrml_utils.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmrml/kmrml/lib/mrml_utils.cpp b/kmrml/kmrml/lib/mrml_utils.cpp
index d493e58d..80c44489 100644
--- a/kmrml/kmrml/lib/mrml_utils.cpp
+++ b/kmrml/kmrml/lib/mrml_utils.cpp
@@ -38,12 +38,12 @@ Util *Util::s_self = 0L;
Util::Util()
{
// we need our own dcopclient, when used in kio_mrml
if ( !DCOPClient::mainClient() )
{
DCOPClient::setMainClient( new DCOPClient() );
if ( !DCOPClient::mainClient()->attach() )
- tqWarning( "kio_mrml: Can't attach to DCOP Server.");
+ tqWarning( "tdeio_mrml: Can't attach to DCOP Server.");
}
}
@@ -38,12 +38,12 @@ Util *Util::s_self = 0L;
Util::Util()
{
- // we need our own dcopclient, when used in kio_mrml
+ // we need our own dcopclient, when used in tdeio_mrml
if ( !DCOPClient::mainClient() )
{